@@ -17,6 +17,10 @@ static char * const my_constant_names[] = {
     "FANN_ELLIOT_SYMMETRIC",
     "FANN_LINEAR_PIECE",
     "FANN_LINEAR_PIECE_SYMMETRIC",
+    "FANN_SIN_SYMMETRIC",
+    "FANN_COS_SYMMETRIC",
+    "FANN_SIN",
+    "FANN_COS",
     "FANN_ERRORFUNC_LINEAR",
     "FANN_ERRORFUNC_TANH",
     "FANN_STOPFUNC_MSE",
@@ -42,6 +46,10 @@ static const unsigned int my_constant_values[] = {
     FANN_ELLIOT_SYMMETRIC,
     FANN_LINEAR_PIECE,
     FANN_LINEAR_PIECE_SYMMETRIC,
+    FANN_SIN_SYMMETRIC,
+    FANN_COS_SYMMETRIC,
+    FANN_SIN,
+    FANN_COS,
     FANN_ERRORFUNC_LINEAR,
     FANN_ERRORFUNC_TANH,
     FANN_STOPFUNC_MSE,
